<?php

namespace Security;

class Helper
{
    /**
     * List all the files in a directory recursively.
     * @static
     * @param string $dir
     * @return array|bool
     */
    public static function list_dir($dir = '.')
    {
        if (!is_dir($dir)) {
            return false;
        }

        $files = array();
        static::list_dir_aux($dir, $files);

        return $files;
    }

    /**
     * List all the routes defined in the application.
     * @static
     * @return array
     */
    public static function list_all_uri()
    {
        $routes = include(APP_PATH . '/routes.php');
        $files = Helper::list_dir(ROUTE_PATH);
        $list = array();

        foreach ($routes as $key => $value) {
            array_push($list, $key);
        }

        foreach ($files as $file) {
            $f = include($file);

            foreach ($f as $key => $value) {
                array_push($list, $key);
            }
        }

        return $list;
    }

    /**
     * List files in a directory.
     * @static
     * @param string $dir
     * @param array $files
     * @return void
     */
    protected static function list_dir_aux($dir, &$files)
    {
        $handle = opendir($dir);

        while (($file = readdir($handle)) !== false) {
            if ($file == '.' || $file == '..') {
                continue;
            }

            $filepath = $dir == '.' ? $file : $dir . '/' . $file;

            if (is_link($filepath)) {
                continue;
            }

            if (is_file($filepath)) {
                $files[] = $filepath;
            } else if (is_dir($filepath)) {
                static::list_dir_aux($filepath, $files);
            }
        }

        closedir($handle);
    }
}
